summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/sqlite/vdbe.c
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-08-09 22:25:47 -0500
commiteaa7ee2e0bbca40ba3173c4304f81957e8964291 (patch)
tree4f793aa48a5080aedc94ce6e519c3b86708f2b88 /tqtinterface/qt4/src/3rdparty/sqlite/vdbe.c
parent79a9d7a46a20d4a0923bc06fc471fdc2176ef865 (diff)
downloadexperimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.tar.gz
experimental-eaa7ee2e0bbca40ba3173c4304f81957e8964291.zip
rename the following methods:
tqfind find tqreplace replace tqcontains contains
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/sqlite/vdbe.c')
-rw-r--r--tqtinterface/qt4/src/3rdparty/sqlite/vdbe.c42
1 files changed, 21 insertions, 21 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/sqlite/vdbe.c b/tqtinterface/qt4/src/3rdparty/sqlite/vdbe.c
index 3ba963d..5171275 100644
--- a/tqtinterface/qt4/src/3rdparty/sqlite/vdbe.c
+++ b/tqtinterface/qt4/src/3rdparty/sqlite/vdbe.c
@@ -5,7 +5,7 @@
** a legal notice, here is a blessing:
**
** May you do good and not evil.
-** May you tqfind forgiveness for yourself and forgive others.
+** May you find forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
*************************************************************************
@@ -233,7 +233,7 @@ static int hardDynamicify(Mem *pStack){
}
/*
** An ephemeral string value (signified by the MEM_Ephem flag) tqcontains
** a pointer to a dynamically allocated string where some other entity
** is responsible for deallocating that string. Because the stack entry
** does not control the string, it might be deleted without the stack
@@ -377,11 +377,11 @@ static Sorter *Merge(Sorter *pLeft, Sorter *pRight){
}
/*
-** The following routine works like a tqreplacement for the standard
+** The following routine works like a replacement for the standard
** library routine fgets(). The difference is in how end-of-line (EOL)
** is handled. Standard fgets() uses LF for EOL under unix, CRLF
** under windows, and CR under mac. This routine accepts any of these
-** character sequences as an EOL mark. The EOL mark is tqreplaced by
+** character sequences as an EOL mark. The EOL mark is replaced by
** a single LF character in zBuf.
*/
static char *vdbe_fgets(char *zBuf, int nBuf, FILE *in){
@@ -1842,7 +1842,7 @@ case OP_MakeRecord: {
** generated record distinct */
char zTemp[NBFS]; /* Temp space for small records */
/* Assuming the record tqcontains N fields, the record format looks
** like this:
**
** -------------------------------------------------------------------
@@ -1856,9 +1856,9 @@ case OP_MakeRecord: {
** and data(N-1) is the top of the stack.
**
** Each of the idx() entries is either 1, 2, or 3 bytes depending on
** how big the total record is. Idx(0) tqcontains the offset to the start
** of data(0). Idx(k) tqcontains the offset to the start of data(k).
** Idx(N) tqcontains the total number of bytes in the record.
*/
nField = pOp->p1;
pRec = &pTos[1-nField];
@@ -2018,7 +2018,7 @@ case OP_MakeKey: {
int nField;
int addRowid;
int i, j;
- int tqcontainsNull = 0;
+ int containsNull = 0;
Mem *pRec;
char zTemp[NBFS];
@@ -2033,7 +2033,7 @@ case OP_MakeKey: {
char *z;
if( flags & MEM_Null ){
nByte += 2;
- tqcontainsNull = 1;
+ containsNull = 1;
}else if( pOp->p3 && pOp->p3[j]=='t' ){
Stringify(pRec);
pRec->flags &= ~(MEM_Int|MEM_Real);
@@ -2092,7 +2092,7 @@ case OP_MakeKey: {
iKey = intToKey(pRec->i);
memcpy(&zNewKey[j], &iKey, sizeof(u32));
popStack(&pTos, nField+1);
- if( pOp->p2 && tqcontainsNull ) pc = pOp->p2 - 1;
+ if( pOp->p2 && containsNull ) pc = pOp->p2 - 1;
}else{
if( pOp->p2==0 ) popStack(&pTos, nField);
}
@@ -2487,7 +2487,7 @@ case OP_OpenTemp: {
/* Opcode: OpenPseudo P1 * *
**
** Open a new cursor that points to a fake table that tqcontains a single
** row of data. Any attempt to write a second row of data causes the
** first row to be deleted. All data is deleted when the cursor is
** closed.
@@ -2525,7 +2525,7 @@ case OP_Close: {
**
** Pop the top of the stack and use its value as a key. Reposition
** cursor P1 so that it points to an entry with a matching key. If
** the table tqcontains no record with a matching key, then the cursor
** is left pointing at the first record that is greater than the key.
** If there are no records greater than the key and P2 is not zero,
** then an immediate jump to P2 is made.
@@ -2804,7 +2804,7 @@ case OP_NewRecno: {
/* The next rowid or record number (different terms for the same
** thing) is obtained in a two-step algorithm.
**
- ** First we attempt to tqfind the largest existing rowid and add one
+ ** First we attempt to find the largest existing rowid and add one
** to that. But if the largest existing rowid is already the maximum
** positive integer, we have to fall through to the second
** probabilistic algorithm
@@ -2815,7 +2815,7 @@ case OP_NewRecno: {
** and try again, up to 1000 times.
**
** For a table with less than 2 billion entries, the probability
- ** of not tqfinding a unused rowid is about 1.0e-300. This is a
+ ** of not finding a unused rowid is about 1.0e-300. This is a
** non-zero probability, but it is still vanishingly small and should
** never cause a problem. You are much, much more likely to have a
** hardware failure than for this algorithm to fail.
@@ -3588,7 +3588,7 @@ case OP_IdxGE: {
/* Opcode: IdxIsNull P1 P2 *
**
-** The top of the stack tqcontains an index entry such as might be generated
+** The top of the stack contains an index entry such as might be generated
** by the MakeIdxKey opcode. This routine looks at the first P1 fields of
** that key. If any of the first P1 fields are NULL, then a jump is made
** to address P2. Otherwise we fall straight through.
@@ -3704,7 +3704,7 @@ case OP_CreateTable: {
** stack the text of an error message describing any problems.
** If there are no errors, push a "ok" onto the stack.
**
** P1 is the index of a set that tqcontains the root page numbers
** for all tables and indices in the main database file. The set
** is cleared by this opcode. In other words, after this opcode
** has executed, the set will be empty.
@@ -4097,7 +4097,7 @@ case OP_SortNext: {
/* Opcode: SortCallback P1 * *
**
** The top of the stack tqcontains a callback record built using
** the SortMakeRec operation with the same P1 value as this
** instruction. Pop this record from the stack and invoke the
** callback on it.
@@ -4151,8 +4151,8 @@ case OP_FileOpen: {
** Read a single line of input from the open file (the file opened using
** FileOpen). If we reach end-of-file, jump immediately to P2. If
** we are able to get another line, split the line apart using P3 as
** a delimiter. There should be P1 fields. If the input line tqcontains
** more than P1 fields, ignore the excess. If the input line tqcontains
** fewer than P1 fields, assume the remaining fields contain NULLs.
**
** Input ends if a line consists of just "\.". A field containing only
@@ -4391,7 +4391,7 @@ case OP_MemIncr: {
/* Opcode: AggReset * P2 *
**
** Reset the aggregator so that it no longer tqcontains any data.
** Future aggregator elements will contain P2 values each.
*/
case OP_AggReset: {
@@ -233,7 +233,7 @@ static int hardDynamicify(Mem *pStack){
}
/*
-** An ephemeral string value (signified by the MEM_Ephem flag) tqcontains
+** An ephemeral string value (signified by the MEM_Ephem flag) contains
** a pointer to a dynamically allocated string where some other entity
** is responsible for deallocating that string. Because the stack entry
@@ -1842,7 +1842,7 @@ case OP_MakeRecord: {
** generated record distinct */
char zTemp[NBFS]; /* Temp space for small records */
- /* Assuming the record tqcontains N fields, the record format looks
+ /* Assuming the record contains N fields, the record format looks
** like this:
**
@@ -1856,9 +1856,9 @@ case OP_MakeRecord: {
**
** Each of the idx() entries is either 1, 2, or 3 bytes depending on
- ** how big the total record is. Idx(0) tqcontains the offset to the start
- ** of data(0). Idx(k) tqcontains the offset to the start of data(k).
- ** Idx(N) tqcontains the total number of bytes in the record.
+ ** how big the total record is. Idx(0) contains the offset to the start
+ ** of data(0). Idx(k) contains the offset to the start of data(k).
+ ** Idx(N) contains the total number of bytes in the record.
*/
nField = pOp->p1;
@@ -2487,7 +2487,7 @@ case OP_OpenTemp: {
/* Opcode: OpenPseudo P1 * *
**
-** Open a new cursor that points to a fake table that tqcontains a single
+** Open a new cursor that points to a fake table that contains a single
** row of data. Any attempt to write a second row of data causes the
** first row to be deleted. All data is deleted when the cursor is
@@ -2525,7 +2525,7 @@ case OP_Close: {
** Pop the top of the stack and use its value as a key. Reposition
** cursor P1 so that it points to an entry with a matching key. If
-** the table tqcontains no record with a matching key, then the cursor
+** the table contains no record with a matching key, then the cursor
** is left pointing at the first record that is greater than the key.
** If there are no records greater than the key and P2 is not zero,
@@ -3704,7 +3704,7 @@ case OP_CreateTable: {
** If there are no errors, push a "ok" onto the stack.
**
-** P1 is the index of a set that tqcontains the root page numbers
+** P1 is the index of a set that contains the root page numbers
** for all tables and indices in the main database file. The set
** is cleared by this opcode. In other words, after this opcode
@@ -4097,7 +4097,7 @@ case OP_SortNext: {
/* Opcode: SortCallback P1 * *
**
-** The top of the stack tqcontains a callback record built using
+** The top of the stack contains a callback record built using
** the SortMakeRec operation with the same P1 value as this
** instruction. Pop this record from the stack and invoke the
@@ -4151,8 +4151,8 @@ case OP_FileOpen: {
** FileOpen). If we reach end-of-file, jump immediately to P2. If
** we are able to get another line, split the line apart using P3 as
-** a delimiter. There should be P1 fields. If the input line tqcontains
-** more than P1 fields, ignore the excess. If the input line tqcontains
+** a delimiter. There should be P1 fields. If the input line contains
+** more than P1 fields, ignore the excess. If the input line contains
** fewer than P1 fields, assume the remaining fields contain NULLs.
**
@@ -4391,7 +4391,7 @@ case OP_MemIncr: {
/* Opcode: AggReset * P2 *
**
-** Reset the aggregator so that it no longer tqcontains any data.
+** Reset the aggregator so that it no longer contains any data.
** Future aggregator elements will contain P2 values each.
*/